==> onos-yang-runtime-2.2.0-b5-sources.jar: org/onosproject/yang/gen/v1/ytbrpc/rev20160826/ytbrpc/content/input/in/DefaultAugmentedIn.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ytbrpc.rev20160826.ytbrpc.content.input.in;

import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ytbrpc.rev20160826.ytbrpc.content.input.in.augmentedin.Real;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of augmentedIn.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultAugmentedIn extends InnerModelObject implements AugmentedIn {
    protected Real real;

    @Override
    public Real real() {
        return real;
    }

    @Override
    public void real(Real real) {
        this.real = real;
    }

    @Override
    public int hashCode() {
        return Objects.hash(real);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultAugmentedIn) {
            DefaultAugmentedIn other = (DefaultAugmentedIn) obj;
            return
                Objects.equals(real, other.real);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("real=" + real)
            .toString();
    }


    /**
     * Creates an instance of defaultAugmentedIn.
     */
    public DefaultAugmentedIn() {
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/ytbrpc/rev20160826/ytbrpc/content/input/in/DefaultAugmentedIn.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ytbrpc.rev20160826.ytbrpc.content.input.in;

import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ytbrpc.rev20160826.ytbrpc.content.input.in.augmentedin.Real;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of augmentedIn.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultAugmentedIn extends InnerModelObject implements AugmentedIn {
    protected Real real;

    @Override
    public Real real() {
        return real;
    }

    @Override
    public void real(Real real) {
        this.real = real;
    }

    @Override
    public int hashCode() {
        return Objects.hash(real);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultAugmentedIn) {
            DefaultAugmentedIn other = (DefaultAugmentedIn) obj;
            return
                Objects.deepEquals(real, other.real);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("real=" + real)
            .toString();
    }


    /**
     * Creates an instance of defaultAugmentedIn.
     */
    public DefaultAugmentedIn() {
    }

}
